summaryrefslogtreecommitdiffstats
path: root/src/kcolorcombo2.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kcolorcombo2.cpp')
-rw-r--r--src/kcolorcombo2.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/kcolorcombo2.cpp b/src/kcolorcombo2.cpp
index 1864081..f55f7af 100644
--- a/src/kcolorcombo2.cpp
+++ b/src/kcolorcombo2.cpp
@@ -26,7 +26,7 @@
#include <kglobalsettings.h>
#include <klocale.h>
#include <kcolordialog.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <kstdaccel.h>
#include <kcolordrag.h>
@@ -68,7 +68,7 @@ KColorPopup::~KColorPopup()
#include <tqcursor.h>
-void KColorPopup::relayout() // FIXME: relayout should NOT redraw the pixmap!
+void KColorPopup::retqlayout() // FIXME: retqlayout should NOT redraw the pixmap!
{
int columnCount = m_selector->columnCount();
int rowCount = m_selector->rowCount();
@@ -240,7 +240,7 @@ void KColorPopup::mouseMoveEvent(TQMouseEvent *event)
m_selectedColumn = (x - FRAME_WIDTH - MARGIN + 2) / (colorWidth + MARGIN);
m_selectedRow = (y - FRAME_WIDTH - MARGIN + 2) / (colorHeight + MARGIN);
- relayout();
+ retqlayout();
update();
}
@@ -288,7 +288,7 @@ void KColorPopup::keyPressEvent(TQKeyEvent *event)
if (row != m_selectedRow || column != m_selectedColumn) {
m_selectedRow = row;
m_selectedColumn = column;
- relayout();
+ retqlayout();
update();
}
}
@@ -491,7 +491,7 @@ void KColorCombo2::newColorArray(int columnCount, int rowCount)
for (int i = 0; i < columnCount; ++i)
m_colorArray[i] = new TQColor[rowCount];
- m_popup->relayout();
+ m_popup->retqlayout();
}
void KColorCombo2::setColorAt(int column, int row, const TQColor &color)
@@ -634,13 +634,13 @@ void KColorCombo2::popup()
TQPoint popupPoint = mapToGlobal(TQPoint(0, 0));
- int popupHeight = m_popup->sizeHint().height();
+ int popupHeight = m_popup->tqsizeHint().height();
if (popupPoint.y() + height() + popupHeight > desk.bottom())
popupPoint.setY(popupPoint.y() - popupHeight);
else
popupPoint.setY(popupPoint.y() + height());
- int popupWidth = m_popup->sizeHint().width();
+ int popupWidth = m_popup->tqsizeHint().width();
if (popupPoint.x() + popupWidth > desk.right())
popupPoint.setX(desk.right() - popupWidth);
@@ -654,7 +654,7 @@ void KColorCombo2::popup()
m_popup->move(popupPoint);
//m_popup->setColor(m_color);
m_popup->doSelection();
- m_popup->relayout(); // FIXME: In aboutToShow() ?
+ m_popup->retqlayout(); // FIXME: In aboutToShow() ?
#if 0
//#ifndef TQT_NO_EFFECTS
if (TQApplication::isEffectEnabled(UI_AnimateCombo)) {
@@ -745,10 +745,10 @@ void KColorCombo2::keyPressEvent(TQKeyEvent *event)
if (KStdAccel::copy().contains(key)) {
TQMimeSource *mime = new KColorDrag(effectiveColor());
- TQApplication::clipboard()->setData(mime, TQClipboard::Clipboard);
+ TQApplication::tqclipboard()->setData(mime, TQClipboard::Clipboard);
} else if (KStdAccel::paste().contains(key)) {
TQColor color;
- KColorDrag::decode(TQApplication::clipboard()->data(TQClipboard::Clipboard), color);
+ KColorDrag::decode(TQApplication::tqclipboard()->data(TQClipboard::Clipboard), color);
setColor(color);
} else
TQComboBox::keyPressEvent(event);
@@ -758,7 +758,7 @@ void KColorCombo2::fontChange(const TQFont &oldFont)
{
// Since the color-rectangle is the same height of the text, we should resize it if the font change:
updateComboBox();
- TQComboBox::fontChange(oldFont); // To update geometry.
+ TQComboBox::fontChange(oldFont); // To update tqgeometry.
}
void KColorCombo2::virtual_hook(int /*id*/, void */*data*/)